==> react-bootstrap-0.10.1-javadoc.jar: transpiled/AffixMixin.js <==
define(
  ["./react-es6","./domUtils","exports"],
  function(__dependency1__, __dependency2__, __exports__) {
    "use strict";
    /* global window, document */

    var React = __dependency1__["default"];
    var domUtils = __dependency2__["default"];

    var AffixMixin = {
      propTypes: {
        offset: React.PropTypes.number,
        offsetTop: React.PropTypes.number,
        offsetBottom: React.PropTypes.number
      },

      getInitialState: function () {
        return {
          affixClass: 'affix-top'
        };
      },

      getPinnedOffset: function (DOMNode) {
        if (this.pinnedOffset) {
          return this.pinnedOffset;
        }

        DOMNode.className = DOMNode.className.replace(/affix-top|affix-bottom|affix/, '');
        DOMNode.className += DOMNode.className.length ? ' affix' : 'affix';

        this.pinnedOffset = domUtils.getOffset(DOMNode).top - window.pageYOffset;

        return this.pinnedOffset;
      },

      checkPosition: function () {
        var DOMNode, scrollHeight, scrollTop, position, offsetTop, offsetBottom,
            affix, affixType, affixPositionTop;

        // TODO: or not visible
        if (!this.isMounted()) {
          return;
        }

        DOMNode = this.getDOMNode();
        scrollHeight = document.documentElement.offsetHeight;
        scrollTop = window.pageYOffset;
        position = domUtils.getOffset(DOMNode);
        offsetTop;
        offsetBottom;

        if (this.affixed === 'top') {
          position.top += scrollTop;
        }

        offsetTop = this.props.offsetTop != null ?
          this.props.offsetTop : this.props.offset;
        offsetBottom = this.props.offsetBottom != null ?
          this.props.offsetBottom : this.props.offset;

        if (offsetTop == null && offsetBottom == null) {
          return;
        }
        if (offsetTop == null) {
          offsetTop = 0;
        }
        if (offsetBottom == null) {
          offsetBottom = 0;
        }

        if (this.unpin != null && (scrollTop + this.unpin <= position.top)) {
          affix = false;
        } else if (offsetBottom != null && (position.top + DOMNode.offsetHeight >= scrollHeight - offsetBottom)) {
          affix = 'bottom';
        } else if (offsetTop != null && (scrollTop <= offsetTop)) {
          affix = 'top';
        } else {
          affix = false;
        }

        if (this.affixed === affix) {
          return;
        }

        if (this.unpin != null) {
          DOMNode.style.top = '';
        }

        affixType = 'affix' + (affix ? '-' + affix : '');

        this.affixed = affix;
        this.unpin = affix === 'bottom' ?
          this.getPinnedOffset(DOMNode) : null;

        if (affix === 'bottom') {
          DOMNode.className = DOMNode.className.replace(/affix-top|affix-bottom|affix/, 'affix-top');
          affixPositionTop = scrollHeight - offsetBottom - DOMNode.offsetHeight - domUtils.getOffset(DOMNode).top;
        }

        this.setState({
          affixClass: affixType,
          affixPositionTop: affixPositionTop
        });
      },

      checkPositionWithEventLoop: function () {
        setTimeout(this.checkPosition, 0);
      },

      componentDidMount: function () {
        window.addEventListener('scroll', this.checkPosition);
        document.addEventListener('click', this.checkPositionWithEventLoop);
      },

      componentWillUnmount: function () {
        window.removeEventListener('scroll', this.checkPosition);
        document.addEventListener('click', this.checkPositionWithEventLoop);
      },

      componentDidUpdate: function (prevProps, prevState) {
        if (prevState.affixClass === this.state.affixClass) {
          this.checkPositionWithEventLoop();
        }
      }
    };

    __exports__["default"] = AffixMixin;
  });

==> react-bootstrap-0.11.0-javadoc.jar: transpiled/AffixMixin.js <==
define(
  ["./react-es6","./domUtils","./react-es6/lib/EventListener","exports"],
  function(__dependency1__, __dependency2__, __dependency3__, __exports__) {
    "use strict";
    /* global window, document */

    var React = __dependency1__["default"];
    var domUtils = __dependency2__["default"];
    var EventListener = __dependency3__["default"];

    var AffixMixin = {
      propTypes: {
        offset: React.PropTypes.number,
        offsetTop: React.PropTypes.number,
        offsetBottom: React.PropTypes.number
      },

      getInitialState: function () {
        return {
          affixClass: 'affix-top'
        };
      },

      getPinnedOffset: function (DOMNode) {
        if (this.pinnedOffset) {
          return this.pinnedOffset;
        }

        DOMNode.className = DOMNode.className.replace(/affix-top|affix-bottom|affix/, '');
        DOMNode.className += DOMNode.className.length ? ' affix' : 'affix';

        this.pinnedOffset = domUtils.getOffset(DOMNode).top - window.pageYOffset;

        return this.pinnedOffset;
      },

      checkPosition: function () {
        var DOMNode, scrollHeight, scrollTop, position, offsetTop, offsetBottom,
            affix, affixType, affixPositionTop;

        // TODO: or not visible
        if (!this.isMounted()) {
          return;
        }

        DOMNode = this.getDOMNode();
        scrollHeight = document.documentElement.offsetHeight;
        scrollTop = window.pageYOffset;
        position = domUtils.getOffset(DOMNode);
        offsetTop;
        offsetBottom;

        if (this.affixed === 'top') {
          position.top += scrollTop;
        }

        offsetTop = this.props.offsetTop != null ?
          this.props.offsetTop : this.props.offset;
        offsetBottom = this.props.offsetBottom != null ?
          this.props.offsetBottom : this.props.offset;

        if (offsetTop == null && offsetBottom == null) {
          return;
        }
        if (offsetTop == null) {
          offsetTop = 0;
        }
        if (offsetBottom == null) {
          offsetBottom = 0;
        }

        if (this.unpin != null && (scrollTop + this.unpin <= position.top)) {
          affix = false;
        } else if (offsetBottom != null && (position.top + DOMNode.offsetHeight >= scrollHeight - offsetBottom)) {
          affix = 'bottom';
        } else if (offsetTop != null && (scrollTop <= offsetTop)) {
          affix = 'top';
        } else {
          affix = false;
        }

        if (this.affixed === affix) {
          return;
        }

        if (this.unpin != null) {
          DOMNode.style.top = '';
        }

        affixType = 'affix' + (affix ? '-' + affix : '');

        this.affixed = affix;
        this.unpin = affix === 'bottom' ?
          this.getPinnedOffset(DOMNode) : null;

        if (affix === 'bottom') {
          DOMNode.className = DOMNode.className.replace(/affix-top|affix-bottom|affix/, 'affix-top');
          affixPositionTop = scrollHeight - offsetBottom - DOMNode.offsetHeight - domUtils.getOffset(DOMNode).top;
        }

        this.setState({
          affixClass: affixType,
          affixPositionTop: affixPositionTop
        });
      },

      checkPositionWithEventLoop: function () {
        setTimeout(this.checkPosition, 0);
      },

      componentDidMount: function () {
        this._onWindowScrollListener =
          EventListener.listen(window, 'scroll', this.checkPosition);
        this._onDocumentClickListener =
          EventListener.listen(document, 'click', this.checkPositionWithEventLoop);
      },

      componentWillUnmount: function () {
        if (this._onWindowScrollListener) {
          this._onWindowScrollListener.remove();
        }

        if (this._onDocumentClickListener) {
          this._onDocumentClickListener.remove();
        }
      },

      componentDidUpdate: function (prevProps, prevState) {
        if (prevState.affixClass === this.state.affixClass) {
          this.checkPositionWithEventLoop();
        }
      }
    };

    __exports__["default"] = AffixMixin;
  });
